package de.intevation.flys.model;

import java.io.Serializable;

import java.math.BigDecimal;

import java.util.List;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.GeneratedValue;
import javax.persistence.Column;
import javax.persistence.SequenceGenerator;
import javax.persistence.GenerationType;
import javax.persistence.OneToOne;
import javax.persistence.OneToMany;
import javax.persistence.OrderBy;
import javax.persistence.JoinColumn;

@Entity
@Table(name = "hyk_entries")
public class HYKEntry
implements   Serializable
{
    private Integer    id;
    private HYK        hyk;
    private BigDecimal km;
    private BigDecimal distanceVL;
    private BigDecimal distanceHF;
    private BigDecimal distanceVR;

    private List<HYKFormation> formations;

    public HYKEntry() {
    }

    public HYKEntry(
        HYK        hyk,
        BigDecimal km,
        BigDecimal distanceVL,
        BigDecimal distanceHF,
        BigDecimal distanceVR
    ) {
        this.hyk        = hyk;
        this.km         = km;
        this.distanceVL = distanceVL;
        this.distanceHF = distanceHF;
        this.distanceVR = distanceVR;
    }

    @Id
    @SequenceGenerator(
        name           = "SEQUENCE_HYK_ENTRIES_ID_SEQ",
        sequenceName   = "HYK_ENTRIES_ID_SEQ",
        allocationSize = 1)
    @GeneratedValue(
        strategy  = GenerationType.SEQUENCE,
        generator = "SEQUENCE_HYK_ENTRIES_ID_SEQ")
    @Column(name = "id")
    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    @OneToOne
    @JoinColumn(name = "hyk_id")
    public HYK getHYK() {
        return hyk;
    }

    public void setHYK(HYK hyk) {
        this.hyk = hyk;
    }

    @Column(name = "km")
    public BigDecimal getKm() {
        return km;
    }

    public void setKm(BigDecimal km) {
        this.km = km;
    }

    @Column(name = "distance_vl")
    public BigDecimal getDistanceVL() {
        return distanceVL;
    }

    public void setDistanceVL(BigDecimal distanceVL) {
        this.distanceVL = distanceVL;
    }

    @Column(name = "distance_hf")
    public BigDecimal getDistanceHF() {
        return distanceHF;
    }

    public void setDistanceHF(BigDecimal distanceHF) {
        this.distanceHF = distanceHF;
    }

    @Column(name = "distance_vr")
    public BigDecimal getDistanceVR() {
        return distanceVR;
    }

    public void setDistanceVR(BigDecimal distanceVR) {
        this.distanceVR = distanceVR;
    }

    @OneToMany
    @OrderBy("formation_num")
    @JoinColumn(name="hyk_entry_id")
    public List<HYKFormation> getFormations() {
        return formations;
    }

    public void setFormations(List<HYKFormation> formations) {
        this.formations = formations;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
